package MainGame;

import java.util.ArrayList;
import java.util.List;

/**
 * The {@code Board} class represents the game board where players place tile sets.
 * It manages the sets of tiles played by the players and provides methods to
 * add new sets, retrieve existing sets, and reset the board.
 */
public class Board {
    private List<List<Tile>> sets;

    /**
     * Constructs a new {@code Board} instance with an empty list of sets.
     */
    public Board() {
        this.sets = new ArrayList<>();
    }

    /**
     * Adds a new set of tiles to the board.
     *
     * @param set The list of tiles forming a valid set.
     */
    public void addSet(List<Tile> set) {
        sets.add(set);
    }

    /**
     * Retrieves the current sets on the board.
     *
     * @return A list containing all tile sets placed on the board.
     */
    public List<List<Tile>> getSets() {
        return sets;
    }

    /**
     * Clears the board by removing all placed tile sets.
     */
    public void cleanBoard() {
        sets.clear();
        System.out.println("DEBUG: Board has been reset.");
    }
}
