package Servers;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.Socket;
import java.util.Scanner;

/**
 * The {@code Client} class represents a client that connects to a Rummikub server.
 * It handles sending player commands to the server and receiving messages from it.
 */
public class Client {
    private String serverAddress;
    private int port;
    private String playerName;

    /**
     * Constructs a {@code Client} instance with the specified server address, port, and player name.
     *
     * @param serverAddress The IP address or hostname of the server.
     * @param port          The port number to connect to.
     * @param playerName    The name of the player connecting to the server.
     */
    public Client(String serverAddress, int port, String playerName) {
        this.serverAddress = serverAddress;
        this.port = port;
        this.playerName = playerName;
    }

    /**
     * Establishes a connection to the server and handles communication.
     * Sends the player's name to the server and listens for server messages.
     */
    public void connect() {
        try (Socket socket = new Socket(serverAddress, port);
             BufferedReader in = new BufferedReader(new InputStreamReader(socket.getInputStream()));
             PrintWriter out = new PrintWriter(socket.getOutputStream(), true);
             Scanner scanner = new Scanner(System.in)) {

            System.out.println("Connected to Rummikub server at " + serverAddress + ":" + port);

            // Send player name to server
            out.println("NAME~" + playerName);

            // Listen for server messages in a separate thread
            Thread listener = new Thread(() -> {
                try {
                    String response;
                    while ((response = in.readLine()) != null) {
                        System.out.println(response);
                    }
                } catch (IOException e) {
                    e.printStackTrace();
                }
            });
            listener.start();

            // Send user commands to the server
            while (true) {
                System.out.println("Enter move (P, M, DRAW, EXIT):");
                String move = scanner.nextLine();
                out.println(move);
                if (move.equalsIgnoreCase("EXIT")) break;
            }

        } catch (IOException e) {
            System.out.println("Failed to connect to server: " + e.getMessage());
        }
    }
}
