package Servers;

import MainGame.Game;
import MainGame.Player;
import MainGame.Tile;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.Socket;
import java.util.ArrayList;
import java.util.List;

/**
 * The {@code ClientHandler} class manages the communication between the server and a connected client.
 * It listens for client messages, processes them, and sends appropriate responses.
 */
class ClientHandler implements Runnable {
    private Socket socket;
    private Server server;
    private PrintWriter out;
    private BufferedReader in;
    private Player player;

    /**
     * Constructs a {@code ClientHandler} for managing an individual client connection.
     *
     * @param socket The socket representing the client's connection.
     * @param server The server instance managing the game.
     */
    public ClientHandler(Socket socket, Server server) {
        this.socket = socket;
        this.server = server;
    }

    /**
     * Runs the client handler thread, handling incoming messages and managing game state updates.
     */
    @Override
    public void run() {
        try {
            in = new BufferedReader(new InputStreamReader(socket.getInputStream()));
            out = new PrintWriter(socket.getOutputStream(), true);

            out.println("WELCOME~Enter your name:");
            String name = in.readLine();
            player = new Player(name);
            server.addPlayer(player);

            out.println("JOINED~" + name);
            server.broadcastGameState();

            String message;
            while ((message = in.readLine()) != null) {
                System.out.println("Client action: " + message);
                String response = server.getGame().processMove(message, player);
                out.println(response);
                server.broadcastGameState();
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /**
     * Sends the current game state to the connected client.
     */
    public void sendGameState() {
        out.println("BOARD~" + server.getGame().getBoard().getSets() + "~TURN~" + server.getGame().getCurrentPlayer().getName());
        out.println("HAND~" + player.getHand());
    }
}
